@@ -39,7 +39,6 @@ import org.apache.ivy.core.event.resolve.EndResolveDependencyEvent;
 import org.apache.ivy.core.event.resolve.StartResolveDependencyEvent;
 import org.apache.ivy.core.module.descriptor.Artifact;
 import org.apache.ivy.core.module.descriptor.Configuration;
-import org.apache.ivy.core.module.descriptor.ConfigurationIntersection;
 import org.apache.ivy.core.module.descriptor.DefaultArtifact;
 import org.apache.ivy.core.module.descriptor.DependencyArtifactDescriptor;
 import org.apache.ivy.core.module.descriptor.DependencyDescriptor;
@@ -853,12 +852,16 @@ public class IvyNode implements Comparable {
                 for (Iterator it = mergedDependencyArtifacts.iterator(); it.hasNext();) {
                     DependencyArtifactDescriptor dad = (DependencyArtifactDescriptor) it.next();
                     Map extraAttributes = new HashMap(dad.getQualifiedExtraAttributes());
-                    // this is later used to know that this is a merged artifact
-                    extraAttributes.put("ivy:merged", 
-                        dad.getDependencyDescriptor().getParentRevisionId() 
-                        + " -> " + usage.getNode().getId()); 
-                    artifacts.add(new MDArtifact(md, dad.getName(), dad.getType(), dad.getExt(),
-                        dad.getUrl(), extraAttributes));
+                    MDArtifact artifact = new MDArtifact(md, dad.getName(), dad.getType(), dad.getExt(),
+                            dad.getUrl(), extraAttributes);
+                    
+                    if (!artifacts.contains(artifact)) {
+                        // this is later used to know that this is a merged artifact
+                        extraAttributes.put("ivy:merged", 
+                            dad.getDependencyDescriptor().getParentRevisionId() 
+                            + " -> " + usage.getNode().getId()); 
+                        artifacts.add(artifact);
+                    }
                 }
             }
         }
